@@ -1,7 +1,9 @@
 import enum
 import typing
+import re
 
 import pydantic
+from qhub.constants import SUPPORTED_TERRAFORM_MINOR_RELEASES
 
 
 class ProviderEnum(str, enum.Enum):
@@ -186,6 +188,15 @@ class Main(Base):
     ci_cd: CiEnum
     security: Security
     profiles: Profiles = []
+    terraform_version: str
+
+    @pydantic.validator("terraform_version")
+    def verify_terraform_version(cls, v):
+        minor_release = re.search(r"(\d+)\.(\d+)", v).group(0)
+        if minor_release not in SUPPORTED_TERRAFORM_MINOR_RELEASES:
+            raise ValueError(
+                f"terraform_version must be defined in qhub-config.yaml and a release of one of the following minor versions: {SUPPORTED_TERRAFORM_MINOR_RELEASES}"
+            )
 
 
 class DigitalOcean(Main):
